@@ -174,8 +174,9 @@ def start_pyrox(other_cfg=None):
     logging_manager = get_log_manager()
     logging_manager.configure(config)
 
-    _LOG.info('Upstream targets are: {}'.format(
-        [dst for dst in config.routing.upstream_hosts]))
+    if config.routing.upstream_hosts is not None:
+        _LOG.info('Upstream targets are: {}'.format(
+            [dst for dst in config.routing.upstream_hosts]))
 
     # Set bind host
     bind_host = config.core.bind_host.split(':')
@@ -220,7 +221,7 @@ you run Pyrox in production with this feature enabled.
     for i in range(num_processes):
         pid = os.fork()
         if pid == 0:
-            print('Starting process {}'.format(i))
+            _LOG.info('Starting process {}'.format(i))
             start_proxy(sockets, config)
             sys.exit(0)
         else:
